compat{a->i}bility
erron{->e}ous
nec{c->}essary.
Either "the" or "a".
Signed-off-by: Philipp Hahn <hahn(a)univention.de>
---
ChangeLog-old | 36 ++++++++++++++++++------------------
docs/drvlxc.html.in | 2 +-
docs/formatdomain.html.in | 4 ++--
docs/locking.html.in | 2 +-
docs/migration.html.in | 2 +-
docs/news.html.in | 6 +++---
src/conf/domain_conf.c | 6 +++---
src/libvirt.c | 2 +-
src/lxc/lxc_container.c | 2 +-
src/qemu/qemu_migration.c | 2 +-
src/rpc/virnetserverprogram.c | 2 +-
src/util/virterror.c | 8 ++++----
src/xenxs/xen_sxpr.c | 2 +-
13 files changed, 38 insertions(+), 38 deletions(-)
diff --git a/ChangeLog-old b/ChangeLog-old
index c3b41e2..b5d44d5 100644
--- a/ChangeLog-old
+++ b/ChangeLog-old
@@ -882,7 +882,7 @@ Wed May 13 18:06:17 CEST 2009 Daniel Veillard
<veillard(a)redhat.com>
Wed May 13 12:34:06 BST 2009 Daniel P. Berrange <berrange(a)redhat.com>
* src/lxc_container.c: Replace sys/capability.h with
- linux/capability.h, to avoid unneccessary dependancy
+ linux/capability.h, to avoid unnecessary dependency
on the libcap package.
Tue May 12 16:39:06 EDT 2009 Cole Robinson <crobinso(a)redhat.com>
@@ -3351,7 +3351,7 @@ Tue Jan 20 20:22:53 GMT 2009 Daniel P. Berrange
<berrange(a)redhat.com>
Tue Jan 20 19:49:53 GMT 2009 Daniel P. Berrange <berrange(a)redhat.com>
* .x-sc_prohibit_nonreentrant: Blacklist some places where
- use of non-threadsafe APIs are not neccessary to check
+ use of non-threadsafe APIs are not necessary to check
* Makefile.am, Makefile.maint, Makefile.nonreentrant: Add
check for non-reentrant safe API calls
* Makefile.cfg: Temporarily disable non-reentrant check
@@ -3591,7 +3591,7 @@ Thu Jan 15 19:54:19 GMT 2009 Daniel P. Berrange
<berrange(a)redhat.com>
* src/Makefile.am, src/threads.c, src/threads.h: Generic internal API for threads
* src/threads-pthread.c, src/threads-pthread.h: UNIX pthreads impl
* src/threads-win32.c, src/threads-win32.h: Win32 threads impl
- * src/internal.h: Remove unnneccessary pthreads macros
+ * src/internal.h: Remove unnecessary pthreads macros
* src/libvirt_private.syms: Add symbols for internal threads API
* po/POTFILES.in: Add node_device_conf.c
* proxy/Makefile.am: Add threads.c to build
@@ -4262,7 +4262,7 @@ Thu Dec 18 11:50:58 GMT 2008 Daniel P. Berrange
<berrange(a)redhat.com>
Misc daemon bug fixes (John Levon)
* qemud/qemud.c: Fix conditional for node devices
- * qemud/remote.c: Remove unneccessary path.h include
+ * qemud/remote.c: Remove unnecessary path.h include
Thu Dec 18 07:47:58 +0100 2008 Jim Meyering <meyering(a)redhat.com>
@@ -5032,7 +5032,7 @@ Tue Nov 25 11:17:40 GMT 2008 Daniel P. Berrange
<berrange(a)redhat.com>
Tue Nov 25 10:49:40 GMT 2008 Daniel P. Berrange <berrange(a)redhat.com>
- * src/Makefile.am: Remove unneccessary $(builddir) usage which
+ * src/Makefile.am: Remove unnecessary $(builddir) usage which
breaks on older automake. Remove duplicate CFLAGS from merge
error
* src/xen_unified.c: Wire up XM driver for autostart
@@ -5093,7 +5093,7 @@ Mon Nov 24 19:22:40 GMT 2008 Daniel P. Berrange
<berrange(a)redhat.com>
* tests/Makefile.am, tests/sexpr2xmltest.c,
tests/testutilsxen.c, tests/xencapstest.c,
tests/xmconfigtest.c, tests/xml2sexprtest.c: Disable all
- Xen tests when Xen driver build is disabled. Remove unneccessary
+ Xen tests when Xen driver build is disabled. Remove unnecessary
WITH_XEN conditionals from source, since the entire build
is disabled in Makefile.am
@@ -6822,7 +6822,7 @@ Wed Aug 20 21:05:09 BST 2008 Daniel P. Berrange
<berrange(a)redhat.com>
src/xen_unified.h, src/xend_internal.c, src/xend_internal.h,
src/xm_internal.c, src/xs_internal.c, src/xs_internal.h
tests/testutils.h: Remove preprocessor conditions for driver
- compilation. Remove unneccessary "extern C" declarations.
+ compilation. Remove unnecessary "extern C" declarations.
Wed Aug 20 20:42:09 BST 2008 Daniel P. Berrange <berrange(a)redhat.com>
@@ -7008,7 +7008,7 @@ Fri Aug 8 16:41:24 BST 2008 Daniel Berrange
<berrange(a)redhat.com>
src/storage_backend_fs.c, src/storage_backend_iscsi.c,
src/storage_backend_logical.c, src/util.c, src/util.h,
src/veth.c, tests/qemuxml2argvtest.c: Fix const-correctness
- of virRun and virExec, and remove unneccessary casts in callers
+ of virRun and virExec, and remove unnecessary casts in callers
Fri Aug 8 16:53:24 CEST 2008 Daniel Veillard <veillard(a)redhat.com>
@@ -7530,7 +7530,7 @@ Wed Jul 16 16:44:27 CEST 2008 Daniel Veillard
<veillard(a)redhat.com>
Sat Jul 12 14:52:59 BST 2008 Daniel P. Berrange <berrange(a)redhat.com>
- * src/qemu_conf.c: Remove unneccessary c-ctype.h include
+ * src/qemu_conf.c: Remove unnecessary c-ctype.h include
Fri Jul 11 20:32:59 BST 2008 Daniel P. Berrange <berrange(a)redhat.com>
@@ -8612,7 +8612,7 @@ Thu May 1 14:10:28 EST 2008 Daniel P. Berrange
<berrange(a)redhat.com>
Tue Apr 29 12:32:28 EST 2008 Daniel P. Berrange <berrange(a)redhat.com>
- * configure.in: Remove compatability macros AC_CHECK_*_ONCE for
+ * configure.in: Remove compatibility macros AC_CHECK_*_ONCE for
now part of onceonly.m4 in gnulib/m4/
Wed Apr 29 18:10:00 CEST 2008 Jim Meyering <meyering(a)redhat.com>
@@ -8628,7 +8628,7 @@ Wed Apr 29 18:10:00 CEST 2008 Jim Meyering
<meyering(a)redhat.com>
Tue Apr 29 11:54:28 EST 2008 Daniel P. Berrange <berrange(a)redhat.com>
- * configure.in: Add compatability macros AC_CHECK_*_ONCE for
+ * configure.in: Add compatibility macros AC_CHECK_*_ONCE for
older autoconf (RHEL-5 vintage)
Tue Apr 29 08:13:28 EST 2008 Daniel P. Berrange <berrange(a)redhat.com>
@@ -10247,7 +10247,7 @@ Fri Jan 25 12:00:00 BST 2008 Richard W.M. Jones
<rjones(a)redhat.com>
Fri Jan 25 10:46:32 CET 2008 Daniel Veillard <veillard(a)redhat.com>
- * src/xen_internal.c: fix an erronous use of VIR_DOMAIN_NONE instead
+ * src/xen_internal.c: fix an erroneous use of VIR_DOMAIN_NONE instead
of VIR_DOMAIN_NOSTATE (both defined as 0, no regression)
Thu Jan 24 18:08:28 CET 2008 Daniel Veillard <veillard(a)redhat.com>
@@ -10283,8 +10283,8 @@ Tue Jan 22 16:27:47 EST 2008 Daniel P. Berrange
<berrange(a)redhat.com>
* configure.ac: Remove use of PKG_CHECK_EXISTS macro. Avoid
lines going over 80 chars wide. Make sasl check automatic
- enable/disable as neccessary.
- * acinclude.m4: Added compatability macro for old pkg-config
+ enable/disable as necessary.
+ * acinclude.m4: Added compatibility macro for old pkg-config
* src/gnutls_1_0_compat.h: Add compat for gnutls_cipher_algorithm_t
Mon Jan 21 18:03:47 CET 2008 Jim Meyering <meyering(a)redhat.com>
@@ -11617,7 +11617,7 @@ Tue Oct 23 17:30:52 CEST 2007 Daniel Veillard
<veillard(a)redhat.com>
Mon Oct 22 22:33:59 CEST 2007 Daniel Veillard <veillard(a)redhat.com>
* src/xen_internal.c src/xen_unified.c src/xen_unified.h
- src/xend_internal.c src/xml.c src/xml.h: commited erronously
+ src/xend_internal.c src/xml.c src/xml.h: committed erroneously
the NUMA patches sent for review on the list in last commit.
But that should not affect non NUMA users so early push should
not be a problem.
@@ -12117,7 +12117,7 @@ Mon Aug 13 21:18:48 EST 2007 Daniel P. Berrange
<berrange(a)redhat.com>
* src/util.h, src/util.c: Allow a file descriptor to be supplied
for STDIN when calling virExec(), or if -1, redirect from /dev/null
* src/qemu_driver.c, src/openvz_driver.c: Pass in -1 for new stdin
- parameter above where neccessary. Patch from Jim Paris
+ parameter above where necessary. Patch from Jim Paris
Mon Aug 13 20:13:48 EST 2007 Daniel P. Berrange <berrange(a)redhat.com>
@@ -15485,7 +15485,7 @@ Fri Aug 4 20:19:23 EDT 2006 Daniel Berrange
<berrange(a)redhat.com>
* src/libvirt.c: Fix off-by-one in validated VCPU number (it is
zero based, not one based).
* include/libvirt/libvirt.h: Add some convenience macros for
- calculating neccessary CPU map lengths & total host CPUs
+ calculating necessary CPU map lengths & total host CPUs
* src/virsh.c: Add 'vcpuinfo' and 'vcpumap' commands
Fri Aug 4 14:45:25 CEST 2006 Daniel Veillard <veillard(a)redhat.com>
@@ -15708,7 +15708,7 @@ Wed Jun 14 13:10:03 EDT 2006 Daniel Veillard
<veillard(a)redhat.com>
Tue Jun 13 14:06:01 EDT 2006 Daniel P. Berrange <berrange(a)redhat.com>
* src/virsh.c: use 'double' instead of 'float' when calculating
- 'CPU time' field for dominfo command, to ensure no unneccessary
+ 'CPU time' field for dominfo command, to ensure no unnecessary
loss of precision converting from nanoseconds to seconds.
Tue Jun 13 18:35:22 EDT 2006 Daniel Veillard <veillard(a)redhat.com>
diff --git a/docs/drvlxc.html.in b/docs/drvlxc.html.in
index 47837d1..c817a9b 100644
--- a/docs/drvlxc.html.in
+++ b/docs/drvlxc.html.in
@@ -35,7 +35,7 @@ mount them use:
<p>
NB, the blkio controller in some kernels will not allow creation of nested
sub-directories which will prevent correct operation of the libvirt LXC
-driver. On such kernels, it may be neccessary to unmount the blkio controller.
+driver. On such kernels, it may be necessary to unmount the blkio controller.
</p>
diff --git a/docs/formatdomain.html.in b/docs/formatdomain.html.in
index 6bf64a6..284e780 100644
--- a/docs/formatdomain.html.in
+++ b/docs/formatdomain.html.in
@@ -2885,8 +2885,8 @@ qemu-kvm -net nic,model=? /dev/null
<dl>
<dt><code>video</code></dt>
<dd>
- The <code>video</code> element is the a container for describing
- video devices. For backwards compatability, if no <code>video</code>
+ The <code>video</code> element is the container for describing
+ video devices. For backwards compatibility, if no <code>video</code>
is set but there is a <code>graphics</code> in domain xml, then
libvirt
will add a default <code>video</code> according to the guest type.
For a guest of type "kvm", the default <code>video</code>
for it is:
diff --git a/docs/locking.html.in b/docs/locking.html.in
index 5a64453..28781a4 100644
--- a/docs/locking.html.in
+++ b/docs/locking.html.in
@@ -76,7 +76,7 @@
<p>
The sanlock daemon must be started on every single host
that will be running virtual machines. So repeat these
- steps as neccessary.
+ steps as necessary.
</p>
<h2><a name="sanlockplugin">libvirt sanlock plugin
configuration</a></h2>
diff --git a/docs/migration.html.in b/docs/migration.html.in
index 3676f0b..9d9d9b9 100644
--- a/docs/migration.html.in
+++ b/docs/migration.html.in
@@ -25,7 +25,7 @@
on the hypervisor in question, but will typically have the lowest computational
costs
by minimising the number of data copies involved. The native data transports will
also
require extra hypervisor-specific network configuration steps by the administrator
when
- deploying a host. For some hypervisors, it might be neccessary to open up a large
range
+ deploying a host. For some hypervisors, it might be necessary to open up a large
range
of ports on the firewall to allow multiple concurrent migration operations.
</p>
diff --git a/docs/news.html.in b/docs/news.html.in
index c8365d9..f8e07f1 100644
--- a/docs/news.html.in
+++ b/docs/news.html.in
@@ -5471,7 +5471,7 @@ and check the <a
href="http://libvirt.org/git/?p=libvirt.git;a=log">GIT log</a>
qemu: Search binaries in PATH instead of hardcoding /usr/bin (Matthias
Bolte),<br/>
Implement QMP support for extracting CPU thread ID (Daniel P.
Berrange),<br/>
Misc fixes to QMP monitor support for QEMU (Daniel P. Berrange),<br/>
- Fix setup of compatability serial devices from console device (Daniel P.
Berrange),<br/>
+ Fix setup of compatibility serial devices from console device (Daniel P.
Berrange),<br/>
Start modernizing configure (Eric Blake),<br/>
Add a rule to check for uses of readlink. (Chris Lalancette),<br/>
Add virConnectGetVersion Python API (Taizo ITO),<br/>
@@ -6025,7 +6025,7 @@ and check the <a
href="http://libvirt.org/git/?p=libvirt.git;a=log">GIT log</a>
Fix a typo in virDiskHasValidPciAddr() (Jiri Denemark),<br/>
Fix a number of small typos (Dan Kenigsberg),<br/>
add doc for graphic and video elements (Florian Vichot),<br/>
- Fix up 'neccessary -> necessary' in a comment. (Chris
Lalancette),<br/>
+ Fix up 'necessary -> necessary' in a comment. (Chris
Lalancette),<br/>
Fix up comments for domainXML{To,From}Native. (Chris Lalancette),<br/>
Simple fix of a comment in qemuStringToArgvEnv. (Chris Lalancette),<br/>
Add a README file to src/ explaining the directory structure (Daniel P.
Berrange),<br/>
@@ -6125,7 +6125,7 @@ and check the <a
href="http://libvirt.org/git/?p=libvirt.git;a=log">GIT log</a>
Pull connection handling code out of doTunnelMigrate (Daniel P.
Berrange),<br/>
Refactor native QEMU migration code (Daniel P. Berrange),<br/>
Don't force dconn to be NULL in virDomainMigrate (Daniel P.
Berrange),<br/>
- Remove unneccessary uri_in parameter from virMigratePrepareTunnel (Daniel P.
Berrange),<br/>
+ Remove unnecessary uri_in parameter from virMigratePrepareTunnel (Daniel P.
Berrange),<br/>
Move the VIR_DRV_FEATURE* constants (Daniel P. Berrange),<br/>
Fix configure.ac message vertical alignment (Daniel P. Berrange),<br/>
cgroup: Fix -Werror breakage (Cole Robinson),<br/>
diff --git a/src/libvirt.c b/src/libvirt.c
index e8473c2..11e2635 100644
--- a/src/libvirt.c
+++ b/src/libvirt.c
@@ -16577,7 +16577,7 @@ error:
* is non-NULL, then only the specific domain will be monitored
*
* Most types of event have a callback providing a custom set of parameters
- * for the event. When registering an event, it is thus neccessary to use
+ * for the event. When registering an event, it is thus necessary to use
* the VIR_DOMAIN_EVENT_CALLBACK() macro to cast the supplied function pointer
* to match the signature of this method.
*
diff --git a/src/lxc/lxc_container.c b/src/lxc/lxc_container.c
index 1c148e2..04af39b 100644
--- a/src/lxc/lxc_container.c
+++ b/src/lxc/lxc_container.c
@@ -432,7 +432,7 @@ static int lxcContainerMountBasicFS(const char *srcprefix, bool
pivotRoot)
int mflags;
} mnts[] = {
/* When we want to make a bind mount readonly, for unknown reasons,
- * it is currently neccessary to bind it once, and then remount the
+ * it is currently necessary to bind it once, and then remount the
* bind with the readonly flag. If this is not done, then the original
* mount point in the main OS becomes readonly too which is not what
* we want. Hence some things have two entries here.
diff --git a/src/qemu/qemu_migration.c b/src/qemu/qemu_migration.c
index 8453a47..6e8ea98 100644
--- a/src/qemu/qemu_migration.c
+++ b/src/qemu/qemu_migration.c
@@ -1317,7 +1317,7 @@ qemuMigrationPrepareDirect(struct qemud_driver *driver,
/* XXX this really should have been a properly well-formed
* URI, but we can't add in tcp:// now without breaking
- * compatability with old targets. We at least make the
+ * compatibility with old targets. We at least make the
* new targets accept both syntaxes though.
*/
/* Caller frees */
diff --git a/src/rpc/virnetserverprogram.c b/src/rpc/virnetserverprogram.c
index d2ede6b..7f589c8 100644
--- a/src/rpc/virnetserverprogram.c
+++ b/src/rpc/virnetserverprogram.c
@@ -384,7 +384,7 @@ virNetServerProgramDispatchCall(virNetServerProgramPtr prog,
if (virNetServerClientNeedAuth(client) &&
dispatcher->needAuth) {
/* Explicitly *NOT* calling remoteDispatchAuthError() because
- we want back-compatability with libvirt clients which don't
+ we want back-compatibility with libvirt clients which don't
support the VIR_ERR_AUTH_FAILED error code */
virNetError(VIR_ERR_RPC,
"%s", _("authentication required"));
diff --git a/src/util/virterror.c b/src/util/virterror.c
index edd5198..fb5ca6f 100644
--- a/src/util/virterror.c
+++ b/src/util/virterror.c
@@ -228,7 +228,7 @@ virErrorGenericFailure(virErrorPtr err)
/*
- * Internal helper to perform a deep copy of the an error
+ * Internal helper to perform a deep copy of an error
*/
static int
virCopyError(virErrorPtr from,
@@ -439,7 +439,7 @@ virResetLastError(void)
* Since 0.6.0, all errors reported in the per-connection object
* are also duplicated in the global error object. As such an
* application can always use virGetLastError(). This method
- * remains for backwards compatability.
+ * remains for backwards compatibility.
*
* Returns a pointer to the last error or NULL if none occurred.
*/
@@ -470,7 +470,7 @@ virConnGetLastError(virConnectPtr conn)
* Since 0.6.0, all errors reported in the per-connection object
* are also duplicated in the global error object. As such an
* application can always use virGetLastError(). This method
- * remains for backwards compatability.
+ * remains for backwards compatibility.
*
* One will need to free the result with virResetError()
*
@@ -683,7 +683,7 @@ virRaiseErrorFull(const char *filename ATTRIBUTE_UNUSED,
/*
* All errors are recorded in thread local storage
- * For compatability, public API calls will copy them
+ * For compatibility, public API calls will copy them
* to the per-connection error object when necessary
*/
to = virLastErrorObject();
diff --git a/src/xenxs/xen_sxpr.c b/src/xenxs/xen_sxpr.c
index 756eb77..f8390ea 100644
--- a/src/xenxs/xen_sxpr.c
+++ b/src/xenxs/xen_sxpr.c
@@ -651,7 +651,7 @@ xenParseSxprSound(virDomainDefPtr def,
int i;
/*
- * Special compatability code for Xen with a bogus
+ * Special compatibility code for Xen with a bogus
* sound=all in config.
*
* NB deliberately, don't include all possible
diff --git a/src/conf/domain_conf.c b/src/conf/domain_conf.c
index 26e24f0..dcb9549 100644
--- a/src/conf/domain_conf.c
+++ b/src/conf/domain_conf.c
@@ -2970,7 +2970,7 @@ virDomainDiskDefParseXML(virCapsPtr caps,
/* People sometimes pass a bogus '' source path
when they mean to omit the source element
completely. eg CDROM without media. This is
- just a little compatability check to help
+ just a little compatibility check to help
those broken apps */
if (source && STREQ(source, ""))
VIR_FREE(source);
@@ -8002,7 +8002,7 @@ static virDomainDefPtr virDomainDefParseXML(virCapsPtr caps,
}
VIR_FREE(nodes);
/* For backwards compatability, if no <video> tag is set but there
* is a <graphics> tag, then we add a single video tag */
if (def->ngraphics && !def->nvideos) {
virDomainVideoDefPtr video;
@@ -9531,7 +9531,7 @@ virDomainDefMaybeAddSmartcardController(virDomainDefPtr def)
/*
* Based on the declared <address/> info for any devices,
- * add neccessary drive controllers which are not already present
+ * add necessary drive controllers which are not already present
* in the XML. This is for compat with existing apps which will
* not know/care about <controller> info in the XML
*/
@@ -8002,7 +8002,7 @@ static virDomainDefPtr virDomainDefParseXML(virCapsPtr caps,
}
VIR_FREE(nodes);
- /* For backwards compatability, if no <video> tag is set but there
+ /* For backwards compatibility, if no <video> tag is set but there
* is a <graphics> tag, then we add a single video tag */
if (def->ngraphics && !def->nvideos) {
--
1.7.1